Unified error handling module
Provides a unified error type and handling for the project.
Structs
- Error
Utils - Error handling utility functions
Type Aliases
- Result
- Unified Result type for the project
Unified error handling module
Provides a unified error type and handling for the project.